@@ -8,6 +8,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/require"
+	"github.com/urfave/cli/v2"
 )
 
 func TestGetApps(t *testing.T) {
@@ -20,7 +21,7 @@ func TestGetApps(t *testing.T) {
 
 func TestGetCtrlAddressFromKeaConfigNonExisting(t *testing.T) {
 	// check reading from non existing file
-	path := "/tmp/non-exisiting-path"
+	path := "/tmp/non-existing-path"
 	address, port := getCtrlAddressFromKeaConfig(path)
 	require.EqualValues(t, 0, port)
 	require.Empty(t, address)
@@ -130,7 +131,8 @@ func TestDetectAllowedLogsKeaUnreachable(t *testing.T) {
 		},
 	})
 
-	sa := NewStorkAgent(am)
+	var settings cli.Context
+	sa := NewStorkAgent(&settings, am)
 
 	require.NotPanics(t, func() { am.detectAllowedLogs(sa) })
 }
