@@ -30,6 +30,7 @@ type App struct {
 	Type      string // currently supported types are: "kea" and "bind9"
 	Active    bool
 	Meta      AppMeta
+	Name      string
 
 	AccessPoints []*AccessPoint
 
@@ -45,12 +46,14 @@ func updateAppAccessPoints(tx *pg.Tx, app *App, update bool) (err error) {
 		for _, point := range app.AccessPoints {
 			types = append(types, point.Type)
 		}
-		q := tx.Model((*AccessPoint)(nil))
-		q = q.Where("app_id = ?", app.ID)
-		q = q.Where("type NOT IN (?)", pg.In(types))
-		_, err = q.Delete()
-		if err != nil {
-			return pkgerrors.Wrapf(err, "problem with removing access points from app %d", app.ID)
+		if len(types) > 0 {
+			q := tx.Model((*AccessPoint)(nil))
+			q = q.Where("app_id = ?", app.ID)
+			q = q.Where("type NOT IN (?)", pg.In(types))
+			_, err = q.Delete()
+			if err != nil {
+				return pkgerrors.Wrapf(err, "problem with removing access points from app %d", app.ID)
+			}
 		}
 	}
 
@@ -269,6 +272,41 @@ func UpdateApp(dbIface interface{}, app *App) ([]*Daemon, []*Daemon, error) {
 	return addedDaemons, deletedDaemons, nil
 }
 
+// Updates specified app's name. It returns app instance with old name and possibly
+// an error. If an error occurs, a nil app is returned.
+func RenameApp(db *pg.DB, id int64, newName string) (*App, error) {
+	app := &App{
+		ID:   id,
+		Name: newName,
+	}
+	// We're going to use the following query:
+	// WITH rename AS (
+	//     UPDATE app SET name = ?
+	//     WHERE id = ?
+	//     RETURNING name
+	// )
+	// SELECT * FROM app WHERE id = ?;
+
+	// This query selects app name before doing and update and performs
+	// the update. The idea for this query was taken from the PostgreSQL
+	// documentation: https://www.postgresql.org/docs/9.1/queries-with.html
+
+	updateQuery := db.Model(app).
+		Column("name").
+		WherePK().
+		Returning("name")
+
+	err := db.Model(app).
+		WithUpdate("rename", updateQuery).
+		WherePK().
+		Select()
+	if err != nil {
+		return nil, pkgerrors.Wrapf(err, "problem with renaming an app %d to %s", app.ID, newName)
+	}
+
+	return app, nil
+}
+
 func GetAppByID(db *pg.DB, id int64) (*App, error) {
 	app := App{}
 	q := db.Model(&app)
@@ -357,6 +395,7 @@ func GetAppsByPage(db *pg.DB, offset int64, limit int64, filterText *string, app
 		text := "%" + *filterText + "%"
 		q = q.WhereGroup(func(qq *orm.Query) (*orm.Query, error) {
 			qq = qq.WhereOr("type ILIKE ?", text)
+			qq = qq.WhereOr("name ILIKE ?", text)
 			qq = qq.WhereOr("meta->>'Version' ILIKE ?", text)
 			qq = qq.WhereOr("machine.address ILIKE ?", text)
 			qq = qq.WhereOr("machine.state->>'Hostname' ILIKE ?", text)
@@ -380,16 +419,23 @@ func GetAppsByPage(db *pg.DB, offset int64, limit int64, filterText *string, app
 	return apps, int64(total), nil
 }
 
-func GetAllApps(db *pg.DB) ([]App, error) {
+// Retrieves all apps from the database. The second argument specifies if
+// the app information must be returned with relations, i.e. with daemons,
+// access points and machines information. If it is set to false, only
+// the data belonging to the app table are returned.
+func GetAllApps(db *pg.DB, withRelations bool) ([]App, error) {
 	var apps []App
 
 	// prepare query
 	q := db.Model(&apps)
-	q = q.Relation("AccessPoints")
-	q = q.Relation("Daemons.KeaDaemon.KeaDHCPDaemon")
-	q = q.Relation("Daemons.Bind9Daemon")
-	q = q.Relation("Daemons.LogTargets")
-	q = q.Relation("Machine")
+
+	if withRelations {
+		q = q.Relation("AccessPoints")
+		q = q.Relation("Daemons.KeaDaemon.KeaDHCPDaemon")
+		q = q.Relation("Daemons.Bind9Daemon")
+		q = q.Relation("Daemons.LogTargets")
+		q = q.Relation("Machine")
+	}
 	q = q.OrderExpr("id ASC")
 
 	// retrieve apps from db
@@ -408,7 +454,7 @@ func DeleteApp(db *pg.DB, app *App) error {
 	return nil
 }
 
-// Returns a list of names of active DHCP deamons. This is useful for
+// Returns a list of names of active DHCP daemons. This is useful for
 // creating commands to be send to active DHCP servers.
 func (app *App) GetActiveDHCPDaemonNames() (daemons []string) {
 	if app.Type != AppTypeKea {
