@@ -2,6 +2,22 @@ import { async, ComponentFixture, TestBed } from '@angular/core/testing'
 
 import { AppDaemonsStatusComponent } from './app-daemons-status.component'
 
+class Daemon {}
+
+class Details {
+    daemons: Daemon[]
+}
+
+class Machine {
+    id = 1
+}
+
+class App {
+    id = 1
+    machine = new Machine()
+    details = new Details()
+}
+
 describe('AppDaemonsStatusComponent', () => {
     let component: AppDaemonsStatusComponent
     let fixture: ComponentFixture<AppDaemonsStatusComponent>
@@ -15,6 +31,7 @@ describe('AppDaemonsStatusComponent', () => {
     beforeEach(() => {
         fixture = TestBed.createComponent(AppDaemonsStatusComponent)
         component = fixture.componentInstance
+        component.app = new App()
         fixture.detectChanges()
     })
 
