@@ -25,6 +25,18 @@ export function datetimeToLocal(d) {
     }
 }
 
+/**
+ * Converts epoch time to local time.
+ *
+ * @param epochTime epoch time in seconds.
+ * @returns Human readable local time.
+ */
+export function epochToLocal(epochTime) {
+    // Date constructor takes epoch time in milliseconds.
+    const d = new Date(epochTime * 1000)
+    return datetimeToLocal(d)
+}
+
 /**
  * Return formatted time duration.
  *
@@ -116,7 +128,7 @@ export function getGrafanaSubnetTooltip(subnet, machine) {
  * and expected flags are passed as flags.
  */
 export function extractKeyValsAndPrepareQueryParams(text, keys, flags) {
-    // find all occurences key=val in the text
+    // find all occurrences key=val in the text
     const re = /(\w+):(\w*)/g
     const matches = []
     let match = re.exec(text)
